@@ -8,16 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_ssm._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-remote-stack", "1.0.29", __name__[0:-6], "cdk-remote-stack@1.0.29.jsii.tgz"
+    "cdk-remote-stack", "2.0.3", __name__[0:-6], "cdk-remote-stack@2.0.3.jsii.tgz"
 )
 
 __all__ = [
